helm

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 2, 2019 License: Apache-2.0 Imports: 34 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Delete

func Delete(hr *v1alpha1.HelmRequest, info *cluster.Info) error

Delete delete a Release from a cluster

func Init

func Init()

Init do a lot of dirty stuff 1. init repo dir 2. update repo index we will mount the repo file from a ConfigMap by default, so this function will do the index update

func IsHelmRequestSynced

func IsHelmRequestSynced(hr *v1alpha1.HelmRequest) bool

IsHelmRequestSynced check if a HelmRequest is synced only if hash is equal and not install to all clusters

func Sync

func Sync(hr *v1alpha1.HelmRequest, info *cluster.Info) (*release.Release, error)

Sync = install + upgrade When sync done, add the release note to HelmRequest status

Types

type IndexSyncer

type IndexSyncer struct {
	// contains filtered or unexported fields
}

IndexSyncer sync helm repo index repeatedly

func NewDefaultIndexSyncer

func NewDefaultIndexSyncer() *IndexSyncer

func (*IndexSyncer) Start

func (i *IndexSyncer) Start(stop <-chan struct{}) error

type Values

type Values = map[string]interface{}

Jump to