Documentation
¶
Index ¶
- func NewChartRepoInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredChartRepoInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredHelmRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredReleaseInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewHelmRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewReleaseInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type ChartRepoInformer
- type HelmRequestInformer
- type Interface
- type ReleaseInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewChartRepoInformer ¶ added in v0.9.0
func NewChartRepoInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewChartRepoInformer constructs a new informer for ChartRepo type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredChartRepoInformer ¶ added in v0.9.0
func NewFilteredChartRepoInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredChartRepoInformer constructs a new informer for ChartRepo type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredHelmRequestInformer ¶
func NewFilteredHelmRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredHelmRequestInformer constructs a new informer for HelmRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredReleaseInformer ¶
func NewFilteredReleaseInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredReleaseInformer constructs a new informer for Release type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewHelmRequestInformer ¶
func NewHelmRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewHelmRequestInformer constructs a new informer for HelmRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewReleaseInformer ¶
func NewReleaseInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewReleaseInformer constructs a new informer for Release type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type ChartRepoInformer ¶ added in v0.9.0
type ChartRepoInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ChartRepoLister
}
ChartRepoInformer provides access to a shared informer and lister for ChartRepos.
type HelmRequestInformer ¶
type HelmRequestInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.HelmRequestLister
}
HelmRequestInformer provides access to a shared informer and lister for HelmRequests.
type Interface ¶
type Interface interface {
// ChartRepos returns a ChartRepoInformer.
ChartRepos() ChartRepoInformer
// HelmRequests returns a HelmRequestInformer.
HelmRequests() HelmRequestInformer
// Releases returns a ReleaseInformer.
Releases() ReleaseInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type ReleaseInformer ¶
type ReleaseInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ReleaseLister
}
ReleaseInformer provides access to a shared informer and lister for Releases.