Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Delete ¶
func Delete(hr *v1alpha1.HelmRequest, info *cluster.Info) error
Delete delete a Release from a cluster
func Init ¶
func Init()
Init do a lot of dirty stuff 1. init repo dir 2. update repo index we will mount the repo file from a ConfigMap by default, so this function will do the index update
func IsHelmRequestSynced ¶
func IsHelmRequestSynced(hr *v1alpha1.HelmRequest) bool
IsHelmRequestSynced check if a HelmRequest is synced only if hash is equal and not install to all clusters
Types ¶
type IndexSyncer ¶
type IndexSyncer struct {
// contains filtered or unexported fields
}
IndexSyncer sync helm repo index repeatedly
func NewDefaultIndexSyncer ¶
func NewDefaultIndexSyncer() *IndexSyncer
func (*IndexSyncer) Start ¶
func (i *IndexSyncer) Start(stop <-chan struct{}) error
Click to show internal directories.
Click to hide internal directories.